@@ -1,12 +1,12 @@
 use v6;
-use PDF::DAO::Stream;
+use PDF::COS::Stream;
 use PDF::Font::Loader::Enc;
 
 class PDF::Font::Loader::Enc::CMap
     is PDF::Font::Loader::Enc {
     has uint32 @!to-unicode;
 
-    submethod TWEAK(PDF::DAO::Stream :$cmap!) {
+    submethod TWEAK(PDF::COS::Stream :$cmap!) {
 
         for $cmap.decoded.Str.lines {
             if /:s^ \d+ beginbfrange/ ff /^endbfrange/ {
