@@ -1,7 +1,8 @@
 use PDF::Content::Font::Enc::Type1;
-
+use PDF::Font::Loader::Enc;
 class PDF::Font::Loader::Enc::Type1
-  is PDF::Content::Font::Enc::Type1 {
+    is PDF::Content::Font::Enc::Type1
+    is PDF::Font::Loader::Enc {
 
   use Font::FreeType::Face;
   use Font::FreeType::Native;
