@@ -7,7 +7,7 @@ class PDF::Font::Loader::FreeType {
     use PDF::Font::Loader::Enc::Identity;
     use PDF::Font::Loader::Enc::Identity-H;
     use PDF::Font::Loader::Enc::Type1;
-    use Font::FreeType;
+    use Font::FreeType:ver(v0.0.9+);
     use Font::FreeType::Face;
     use Font::FreeType::Error;
     use Font::FreeType::Native;
@@ -19,18 +19,22 @@ class PDF::Font::Loader::FreeType {
     use PDF::Font::Loader::Enc;
     has PDF::Font::Loader::Enc $!encoder handles <decode>;
     has $.font-stream is required;
+    use PDF::Content:ver(v0.2.3+);
     use PDF::Content::Font;
     has PDF::Content::Font $!dict;
     has UInt $.first-char;
     has UInt $.last-char;
-    has uint16 @.widths;
+    has uint16 @!widths; method widths {@!widths}
     my subset EncodingScheme where 'mac'|'win'|'zapf'|'sym'|'identity'|'identity-h'|PDF::Font::Loader::Enc;
     has EncodingScheme $!enc;
     has Bool $.embed = True;
 
-    submethod TWEAK(:@differences, :$!enc = self!font-format eq 'Type1' || ! $!embed || $!face.num-glyphs <= 255
+    submethod TWEAK(:@differences,
+                    List :$widths,
+                    :$!enc = self!font-format eq 'Type1' || ! $!embed || $!face.num-glyphs <= 255
             ?? 'win'
             !! 'identity-h') {
+        @!widths = .List with $widths;
         die "can't use identity-h encoding with type-1 fonts"
             if self!font-format eq 'Type1' && $!enc eq 'identity-h';
         die "can't use identity-h encoding with unembedded fonts"
@@ -98,7 +102,7 @@ class PDF::Font::Loader::FreeType {
     }
 
     method !font-file {
-        my $decoded = PDF::IO::Blob.new: $!font-stream;
+        my PDF::IO::Blob $decoded .= new: $!font-stream;
 
         my %dict = :Length1($!font-stream.bytes);
         %dict<Filter> = :name<FlateDecode>
@@ -210,7 +214,7 @@ class PDF::Font::Loader::FreeType {
             @cmap-range.push: 'endbfrange';
         }
 
-        my $writer = PDF::Writer.new;
+        my PDF::Writer $writer .= new;
         my $cmap-name = $writer.write: $CMapName;
         my $postscript-name = $writer.write: :literal($.font-name);
 
@@ -282,7 +286,7 @@ class PDF::Font::Loader::FreeType {
         my FT_Pos $x = 0;
         my FT_Pos $y = 0;
         my FT_UInt $prev-idx = 0;
-        my $kerning = FT_Vector.new;
+        my FT_Vector $kerning .= new;
         my $struct = $!face.struct;
         my $glyph-slot = $struct.glyph;
         my Numeric $stringwidth = 0;
@@ -313,7 +317,7 @@ class PDF::Font::Loader::FreeType {
         my $face-struct = $!face.struct;
         my $glyph-slot = $face-struct.glyph;
         my $scale = 1000 / ($!face.units-per-EM || 1000);
-        my FT_UInt $idx =  $face-struct.FT_Get_Char_Index( $char-code );
+        my FT_UInt $idx = $face-struct.FT_Get_Char_Index( $char-code );
         if $idx {
             ft-try({ $face-struct.FT_Load_Glyph( $idx, FT_LOAD_NO_SCALE); });
             $glyph-slot.metrics.height * $scale;
